"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var react_native_1 = require("react-native");
var View_1 = require("./View");
var Text_1 = require("./Text");
var Button_1 = require("./Button");
var Log_1 = require("../../modules/logger/Log");
var Theme_1 = require("../../modules/theme/Theme");
var ModalItem = (function (_super) {
    __extends(ModalItem, _super);
    function ModalItem() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.state = {
            top: new react_native_1.Animated.Value(-100),
            fade: new react_native_1.Animated.Value(0),
            itemHeight: 0
        };
        return _this;
    }
    ModalItem.prototype.onLayout = function (event) {
        var itemHeight = event.nativeEvent.layout.height;
        this.setState({ itemHeight: itemHeight });
        Log_1.default.info('[ModalItem]', itemHeight);
    };
    ModalItem.prototype.show = function () {
        var _this = this;
        if (this.animation) {
            this.animation.stop();
        }
        requestAnimationFrame(function () {
            _this.animation = react_native_1.Animated.parallel([
                react_native_1.Animated.timing(_this.state.fade, {
                    toValue: 1,
                    duration: 600
                }),
                react_native_1.Animated.spring(_this.state.top, {
                    toValue: 0,
                    friction: 8
                })
            ]);
            _this.animation.start();
        });
    };
    ModalItem.prototype.hide = function (cb) {
        var _this = this;
        var offset = this.state.itemHeight < 1 ? 50 : this.state.itemHeight;
        if (this.animation) {
            this.animation.stop();
        }
        requestAnimationFrame(function () {
            _this.animation = react_native_1.Animated.parallel([
                react_native_1.Animated.timing(_this.state.fade, {
                    toValue: 0,
                    duration: 100
                })
            ]);
            _this.animation.start(cb);
        });
    };
    ModalItem.prototype.componentDidMount = function () {
        this.show();
        this.autoDismissSetup();
    };
    ModalItem.prototype.componentWillUnmount = function () {
        if (this.animation) {
            this.animation.stop();
        }
    };
    ModalItem.prototype.autoDismissSetup = function () {
        var _this = this;
        var item = this.props.item || {};
        if (this.timeoutDismiss) {
            clearTimeout(this.timeoutDismiss);
        }
        if (item.autoDismiss) {
            this.timeoutDismiss = setTimeout(function () {
                _this.props.onHide();
            }, item.autoDismiss * 1000);
        }
    };
    ModalItem.prototype.componentDidUpdate = function (prevProps, prevState) {
        var autoDismissReload = false;
        var item = this.props.item || {};
        var prevItem = prevProps.item || {};
        if (prevItem.autoDismiss !== item.autoDismiss) {
            autoDismissReload = true;
        }
        autoDismissReload && this.autoDismissSetup();
    };
    ModalItem.prototype.render = function () {
        var item = this.props.item;
        var _a = this.state, fade = _a.fade, top = _a.top;
        // let level = item.level || 'default';
        return (React.createElement(View_1.default, { style: [styles.container, item.containerStyle] },
            React.createElement(react_native_1.Animated.View, { style: { zIndex: 10, opacity: fade, marginTop: top } },
                React.createElement(View_1.default, { onLayout: this.onLayout.bind(this), style: [styles.content] },
                    item.title &&
                        React.createElement(View_1.default, { style: [styles.header] },
                            typeof item.title === 'object' && item.title,
                            typeof item.title !== 'object' &&
                                React.createElement(Text_1.default, { style: styles.title }, item.title)),
                    item.body &&
                        React.createElement(View_1.default, { style: [styles.body] },
                            typeof item.body === 'object' && item.body,
                            typeof item.body !== 'object' &&
                                React.createElement(Text_1.default, { style: styles.bodyText }, item.body)),
                    item.actions &&
                        React.createElement(View_1.default, { style: [styles.footer] }, item.actions.map(function (action, index) {
                            return React.createElement(Button_1.default, __assign({ key: index }, action));
                        })))),
            React.createElement(react_native_1.Animated.View, { style: [styles.backdrop, { opacity: fade }] })));
    };
    return ModalItem;
}(React.PureComponent));
exports.default = ModalItem;
var styles = react_native_1.StyleSheet.create({
    container: {
        zIndex: 10,
        position: 'absolute',
        alignItems: 'center',
        justifyContent: 'center',
        right: 0,
        left: 0,
        top: 0,
        bottom: 0
    },
    backdrop: {
        backgroundColor: Theme_1.default.vars.modalItemBackgroundColor,
        zIndex: 9,
        //flex: 1,
        //position: Platform.OS === 'web' ? 'fixed' : 'absolute',
        position: 'absolute',
        right: 0,
        left: 0,
        top: 0,
        bottom: 0
    },
    content: {
        margin: 10,
        backgroundColor: Theme_1.default.vars.modalItemContentBackgroundColor,
        borderRadius: 4,
        flexDirection: 'column'
    },
    title: {
        fontSize: 14,
        fontWeight: 'bold',
        color: Theme_1.default.vars.modalItemTextColor
    },
    header: {
        padding: 20
    },
    body: {
        borderTopWidth: 1,
        borderTopColor: Theme_1.default.vars.modalItemBorderColor
    },
    bodyText: {
        padding: 5
    },
    footer: {
        flexDirection: 'row',
        padding: 10,
        borderTopWidth: 1,
        borderTopColor: Theme_1.default.vars.modalItemBorderColor
    }
});
